Page 96 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 96

Home

    The organization that House founded, the Council on
    Foreign Relations (CFR), was to become the hidden
    government of the United States. From its original
    membership list of 210 men, the Council on Foreign
    Relations has grown to include 3,000 of the most
    prominent leaders in America. For decades it has

    controlled United States foreign policy and has operated
    on the secret side of history, shielded from public view.

    To guard against exposure, and to mold public
    opinion, as far back as 1915 the powerful men in
    America working for world government set out to control
    the news media. They accomplished this by employing
    12 leading men in the newspaper field to find out what
    was necessary to control the general policy of the daily
    press throughout the country. It was decided that this
    could be accomplished by purchasing control of 25 of the
    greatest papers. Thus, while the Council on Foreign
    Relations was working to remake the world, for the first
    35 years of its existence, no feature article about it

    appeared in the news media. It was not until the 1960s
    that this near total control of the media began to be

    For decades many top officials of the United States
    Government have been members of the Council on

    fourteen

    of

    fourteen

    state,

    fourteen secretaries of state, fourteen treasury
    secretaries, eleven defense secretaries, and scores of

    91

    Building Modern Babylon

    of this dream come true for the United States.

    circumvented.

    Foreign Relations.

    This includes many presidents,

    secretaries

    other federal department heads.